@@ -35,7 +35,8 @@ class DomainsHandler(BaseHandler):
                 "violationCount": violation_count,
                 "pageCount": page_count,
                 "reviewCount": review_count,
-                "reviewPercentage": review_percentage
+                "reviewPercentage": review_percentage,
+                "is_active": domain.is_active,
             })
 
         self.write_json(result)
@@ -66,7 +67,8 @@ class DomainDetailsHandler(BaseHandler):
             "pageCount": page_count,
             "reviewCount": review_count,
             "violationCount": violation_count,
-            "reviewPercentage": review_percentage
+            "reviewPercentage": review_percentage,
+            "is_active": domain.is_active,
         }
 
         self.write_json(domain_json)
@@ -137,3 +139,16 @@ class DomainReviewsHandler(BaseHandler):
             })
 
         self.write_json(result)
+
+
+class DomainsChangeStatusHandler(BaseHandler):
+
+    @coroutine
+    def post(self, domain_name):
+        domain = Domain.get_domain_by_name(domain_name, self.db)
+
+        if not domain:
+            self.set_status(404, 'Domain %s not found' % domain_name)
+            return
+
+        domain.is_active = not domain.is_active
