@@ -1,7 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import sys
 from os.path import join
 import urlparse
 import inspect
@@ -12,15 +11,13 @@ import codecs
 from box.util.rotunicode import RotUnicode
 codecs.register(RotUnicode.search_function)
 
-import requests
-from requests.exceptions import ConnectionError
 import lxml.html
 import logging
-from ujson import dumps
 
 from holmes.config import Config
 from holmes.facters import Facter
 from holmes.validators.base import Validator
+from holmes.models import Page
 
 
 class InvalidReviewError(RuntimeError):
@@ -64,8 +61,14 @@ class ReviewDAO(object):
 
 class Reviewer(object):
     def __init__(
-            self, api_url, page_uuid, page_url, page_score, ping_method=None, config=None, validators=[], facters=[],
-            async_get=None, wait=None, wait_timeout=None):
+            self, api_url, page_uuid, page_url, page_score, ping_method=None,
+            increase_lambda_tax_method=None, config=None, validators=[], facters=[],
+            async_get=None, wait=None, wait_timeout=None, db=None, cache=None, publish=None,
+            fact_definitions=None, violation_definitions=None):
+
+        self.db = db
+        self.cache = cache
+        self.publish = publish
 
         self.api_url = api_url
 
@@ -74,6 +77,7 @@ class Reviewer(object):
         self.page_score = page_score
 
         self.ping_method = ping_method
+        self.increase_lambda_tax_method = increase_lambda_tax_method
 
         self.review_dao = ReviewDAO(self.page_uuid, self.page_url)
 
@@ -112,6 +116,9 @@ class Reviewer(object):
         self._wait_for_async_requests = wait
         self._wait_timeout = wait_timeout
 
+        self.fact_definitions = fact_definitions
+        self.violation_definitions = violation_definitions
+
     def ping(self):
         if self.ping_method is not None:
             self.ping_method()
@@ -120,20 +127,6 @@ class Reviewer(object):
         if self.async_get_func:
             self.async_get_func(url, handler, method, **kw)
 
-    def _get(self, url):
-        #if self.proxies:
-            #logging.debug('Getting "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
-            #return requests.get(url, proxies=self.proxies)
-
-        return requests.get(url)
-
-    def _post(self, url, data):
-        #if self.proxies:
-            #logging.debug('Posting to "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
-            #return requests.post(url, data=data, proxies=self.proxies)
-
-        return requests.post(url, data=data)
-
     def review(self):
         self.load_content(self.content_loaded)
         self.wait_for_async_requests()
@@ -176,13 +169,6 @@ class Reviewer(object):
         except (lxml.etree.XMLSyntaxError, lxml.etree.ParserError):
             self._current.html = None
 
-            # can't do this there, this is not a validator
-            #self.add_violation(
-                #key='invalid.content',
-                #title='Invalid Content',
-                #description='Fail to parse content from %s' % url,
-                #points=1000)
-
         self.run_facters()
         self.wait_for_async_requests()
 
@@ -220,57 +206,30 @@ class Reviewer(object):
         return join(self.api_url.rstrip('/'), url.lstrip('/'))
 
     def increase_lambda_tax(self, tax):
-        post_url = self.get_url('/tax')
-        response = self._post(post_url, data={'tax': tax})
-
-        if response.status_code > 399:
-            logging.error('Failed to increase lambda tax by %.2f (Status: %s, Text: %s)' % (
-                tax,
-                response.status_code,
-                response.text
-            ))
+        self.increase_lambda_tax_method(tax)
 
     def enqueue(self, urls):
         if not urls:
             return
 
-        #if isinstance(urls, basestring):
-            #post_url = self.get_url('/page')
-            #data = dumps({
-                #'url': urls,
-                #'origin_uuid': str(self.page_uuid)
-            #})
-            #error_message = "Could not enqueue page '" + urls + "'! Status Code: %d, Error: %s"
+        with self.db.begin():
+            for url, score in urls:
+                Page.add_page(
+                    self.db, self.cache,
+                    url, score,
+                    self.async_get_func,
+                    self.publish,
+                    self.handle_page_added
+                )
 
-            #response = self._post(post_url, data=data)
+        self.wait_for_async_requests()
 
-            #if response.status_code > 399:
-                #logging.error(error_message % (
-                    #response.status_code,
-                    #response.text
-                #))
-        #else:
-        post_url = self.get_url('/page')
-        #post_url = self.get_url('/pages')
+    def handle_page_added(self, url, result, page):
+        if not result:
+            error_message = "Could not enqueue page '" + url + "'! Error: %s"
+            logging.error(error_message % page)
 
-        for url, score in urls:
-            data = dumps({
-                'url': url,
-                'score': score,
-                'origin_uuid': str(self.page_uuid)
-            })
-
-            error_message = "Could not enqueue page '" + url + "'! Status Code: %d, Error: %s"
-
-            response = self._post(post_url, data=data)
-
-            if response.status_code > 399:
-                logging.error(error_message % (
-                    response.status_code,
-                    response.text
-                ))
-
-            self.ping()
+        self.ping()
 
     def add_fact(self, key, value):
         self.review_dao.add_fact(key, value)
@@ -279,26 +238,15 @@ class Reviewer(object):
         self.review_dao.add_violation(key, value, points)
 
     def save_review(self):
-        url = self.get_url('/page/%s/review/' % (self.page_uuid))
+        from holmes.models import Review
 
-        try:
-            data = dumps(self.review_dao.to_dict())
-            response = self._post(url, data={
-                'review': data
-            })
-        except ConnectionError:
-            err = sys.exc_info()[1]
-            logging.error("Could not save review! ConnectionError - %s (%s)" % (
-                url,
-                str(err)
-            ))
-            return
+        data = self.review_dao.to_dict()
 
-        if response.status_code > 399:
-            logging.error("Could not save review! Status Code: %d, Error: %s" % (
-                response.status_code,
-                response.text
-            ))
+        Review.save_review(
+            self.page_uuid, data, self.db,
+            self.fact_definitions, self.violation_definitions,
+            self.cache, self.publish
+        )
 
     def wait_for_async_requests(self):
         self._wait_for_async_requests(self._wait_timeout)
